@@ -1,7 +1,7 @@
 from datetime import datetime
 import statistics as stat
 from .top_up import top_up, TopUpDTO
-from ...models.const import (
+from ...models.hourselection.const import (
     CAUTIONHOURTYPE_SUAVE,
     CAUTIONHOURTYPE_INTERMEDIATE,
     CAUTIONHOURTYPE
@@ -17,7 +17,7 @@ class HourTypeList(Enum):
     DynCautionHour = 2
 
 
-class Hoursselectionbase:
+class Hoursselection:
     def __init__(
             self,      
             absolute_top_price: float = 0,
