@@ -69,6 +69,7 @@ LOCALES = [
     LOCALE_NO_TENSIO,
     LOCALE_SE_BJERKE_ENERGI,
     LOCALE_SE_FALBYDGENS_ENERGI,
+    LOCALE_SE_GOTHENBURG,
     LOCALE_SE_KRISTINEHAMN,
     LOCALE_SE_LINDE_ENERGI,
     LOCALE_SE_MALUNG_SALEN,
@@ -81,5 +82,19 @@ LOCALES = [
     LOCALE_DEFAULT
     ]
 
-class LocaleBase:
-    pass
+
+class LocaleData:
+    def __init__(self, input_type:str, domain:str):
+        self._data = None
+        self._type = input_type
+        self._domain = domain
+
+        self._data = LOCALETYPEDICT[input_type]
+
+    @property
+    def type(self) -> str:
+        return self._type
+
+    @property
+    def data(self):
+        return self._data
