@@ -1,10 +1,31 @@
+from datetime import datetime
 from ...util import _convert_quarterly_minutes
 from ...PeaqErrors import PeaqValueError
 
 
-class PredictionBase:
+class Prediction:
+    def __init__(self, hub = None):
+        self._hub = hub
+
+    @property
+    def predictedenergy(self) -> float:
+        return Prediction._predicted_energy(
+            datetime.now().minute,
+            datetime.now().second,
+            self._hub.powersensormovingaverage.value if self._hub.powersensormovingaverage.value is not None else 0,
+            self._hub.totalhourlyenergy.value,
+            self._hub.locale.data.is_quarterly(self._hub.locale.data)
+        )
+
+    @property
+    def predictedpercentageofpeak(self) -> float:
+        return Prediction._predicted_percentage_of_peak(
+            self._hub.current_peak.value,
+            self.predictedenergy
+        )
+
     @staticmethod
-    def predicted_energy(
+    def _predicted_energy(
             now_min: int,
             now_sec: int,
             power_avg: float,
@@ -26,7 +47,7 @@ class PredictionBase:
         return round(ret, 3)
 
     @staticmethod
-    def predicted_percentage_of_peak(
+    def _predicted_percentage_of_peak(
             peak: float,
             predicted_energy: float
     ) -> float:
